@@ -42,7 +42,8 @@ class ALMACENACAU(object):
             )
         if isinstance(file_path, list):
             df = pd.DataFrame(data=file_path)
-            df['data_baixa'].fillna(REE_END_DATE, inplace=True)
+            df['data_baixa'] = df['data_baixa'].apply(
+                lambda x: REE_END_DATE if not isinstance(x, pd.Timestamp) else x.strftime('%Y%m%d'))
             df['data_alta'] = df['data_alta'].apply(lambda x: x.strftime('%Y%m%d'))
             df['tecnologia_emmagatzematge'] = df['tecnologia_emmagatzematge'].astype(str)
             df['tecnologia_emmagatzematge'] = df['tecnologia_emmagatzematge'].apply(lambda x: x.zfill(2))
